<?php

declare(strict_types=1);

namespace Drupal\media_crowdriff\Plugin\Validation\Constraint;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates Crowdriff embed code and URIs.
 */
class MediaCrowdriffConstraintValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   */
  public function validate($value, Constraint $constraint) {
    /** @var \Drupal\media\MediaInterface $media */
    $media = $value->getEntity();
    $source = $media->getSource();

    $url = $source->getSourceFieldValue($media);
    $url = trim($url, "/");
    // The URL may be NULL if the source field is empty, which is invalid input.
    if (empty($url)) {
      $this->context->addViolation($constraint->emptyUrlMessage);
      return;
    }

    $pattern = $this->getIdRegexPattern();
    if (!preg_match($pattern, $url)) {
      $this->context->addViolation($constraint->invalidUrlMessage);
    }
  }

  /**
   * Gets the regex pattern for matching Crowdriff embed IDs.
   *
   * @return string
   *   Returns a string containing the regex pattern.
   */
  public static function getIdRegexPattern() {
    return '/^cr-init__\w+/';
  }

}
